==> HostCMS.Free_6.7.tar.gz: modules/shop/delivery/i18n/ru.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Типы доставки',
	'show_type_of_delivery_title' => "Типы доставки",
	'show_type_of_delivery_link' => "Типы доставки",
	'show_type_of_delivery_link_add' => "Добавить",
	'type_of_delivery_add_form_title' => "Добавление типа доставки",
	'type_of_delivery_edit_form_title' => "Редактирование типа доставки",
	'payment_systems' => "Платежные системы",
	'payment_systems_not_specified' => 'Платежные системы не указаны',
	'name' => "<acronym title=\"Название типа доставки\">Название</acronym>",
	'sorting' => "Порядок сортировки",
	'active' => "<acronym title=\"Активность типа доставки\">Активность типа доставки</acronym>",
	'description' => "<acronym title=\"Описание типа доставки\">Описание</acronym>",
	'image' => "<acronym title=\"Изображение типа доставки\">Изображение</acronym>",
	'id' => "Идентификатор",
	'shop_id' => "Идентификатор магазина",
	'delivery' => 'Доставка "%s"',
	'edit_success' => "Тип доставки успешно добавлен!",
	'edit_error' => "Ошибка! Тип доставки не добавлен!",
	'apply_success' => "Информация успешно изменена",
	'copy_success' => "Информация успешно скопирована!",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'markDeleted_success' => "Информация о типе доставки успешно удалена!",
	'changeStatus_success' => "Информация успешно изменена",
	'option0' => 'Условия',
	'option1' => 'По формуле',
	'handler' => 'Код обработчика',
	'method' => 'Способ доставки',
	'pickup' => 'Самовывоз',
	'post' => 'Почта',
	'courier' => 'Курьерская доставка',
	'days_from' => 'Дней доставки от',
	'days_to' => 'до',
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/delivery/i18n/ru.php <==
<?php

return array(
	'model_name' => 'Типы доставки',
	'show_type_of_delivery_title' => "Типы доставки",
	'show_type_of_delivery_link' => "Типы доставки",
	'show_type_of_delivery_link_add' => "Добавить",
	'type_of_delivery_add_form_title' => "Добавление типа доставки",
	'type_of_delivery_edit_form_title' => 'Редактирование типа доставки "%s"',
	'payment_systems' => "Платежные системы",
	'payment_systems_not_specified' => 'Платежные системы не указаны',
	'name' => "Название",
	'sorting' => "Порядок сортировки",
	'active' => "Активность",
	'description' => "Описание",
	'image' => "Изображение",
	'id' => "Идентификатор",
	'shop_id' => "Идентификатор магазина",
	'delivery' => 'Доставка "%s"',
	'delivery_with_condition' => 'Доставка "%s: %s"',
	'edit_success' => "Тип доставки успешно добавлен!",
	'edit_error' => "Ошибка! Тип доставки не добавлен!",
	'apply_success' => "Информация успешно изменена",
	'copy_success' => "Информация успешно скопирована!",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'markDeleted_success' => "Информация о типе доставки успешно удалена!",
	'changeStatus_success' => "Информация успешно изменена",
	'option0' => 'Условия',
	'option1' => 'По формуле',
	'handler' => 'Код обработчика',
	'method' => 'Способ доставки',
	'pickup' => 'Самовывоз',
	'post' => 'Почта',
	'courier' => 'Курьерская доставка',
	'days_from' => 'Дней доставки от',
	'days_to' => 'до',
	'guid' => 'GUID',
	'conditions_for_delivery' => 'Условия доставки для "%s"',
	'empty_conditions_for_delivery' => 'Условия доставки отсутствуют',
	'apply_button' => 'Применить',
	'intervals' => 'Интервалы',
);
